@@ -1,11 +1,11 @@
 /*
     AWFFull - A Webalizer Fork, Full o' features
     
-    $Id: awffull.h 265 2006-08-27 05:06:10Z steve $
+    $Id: awffull.h 380 2007-04-13 11:38:23Z steve $
 
     Copyright (C) 1997-2001  Bradford L. Barrett (brad@mrunix.net)
     Copyright 2002, 2004 by Stanislaw Yurievich Pusep
-    Copyright (C) 2004, 2005, 2006 by Stephen McInerney (spm@stedee.id.au)
+    Copyright (C) 2004, 2005, 2006, 2007 by Stephen McInerney (spm@stedee.id.au)
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -36,16 +36,6 @@
 
 #include "common.h"
 
-/* Internationalisation stuff */
-#include <libintl.h>
-#include <locale.h>
-#include "gettext.h"
-
-#define _(String) gettext (String)
-#define gettext_noop(String) String
-#define N_(String) gettext_noop (String)
-
-
 #define FILENAME_CONFIG     "awffull.conf"
 #define FILENAME_HISTORY    "awffull.hist"
 #define FILENAME_CURRENT    "awffull.current"
@@ -72,6 +62,11 @@
 #define MAXIDENT 64                             /* Max size of ident string (user)  */
 #define MAXHISTLEN (20 * 12)                    /* Maximum length of the history - 20 years */
 
+#define MAXPATHNAMELENGTH   4096
+#define MAXFILENAMELENGTH   1024
+#define MAXTITLELENGTH      1024
+#define MAXCSSLENGTH        1024
+
 #define SLOP_VAL 3600                           /* out of sequence slop (seconds)   */
 
 
@@ -307,6 +302,7 @@ extern int graph_hourly_x;                      /* Size of Daily Graph X
 extern int graph_hourly_y;                      /* Size of Daily Graph Y        */
 extern int graph_pie_x;                         /* Size of Pie Graph X  */
 extern int graph_pie_y;                         /* Size of Pie Graph Y  */
+extern bool use_kanji;                          /* Do special offsets in graphs for Japanese Character Set */
 
 extern int ntop_sites;                          /* top n sites to display   */
 extern int ntop_sitesK;                         /* top n sites (by kbytes)  */
