@@ -1,7 +1,7 @@
 /*
     AWFFull - A Webalizer Fork, Full o' features
     
-    $Id: preserve.c 250 2006-08-02 07:34:25Z steve $
+    $Id: preserve.c 350 2007-01-19 09:20:00Z steve $
 
     Copyright (C) 1997-2001  Bradford L. Barrett (brad@mrunix.net)
     Copyright (C) 2004, 2005, 2006 by Stephen McInerney (spm@stedee.id.au)
@@ -194,48 +194,49 @@ save_state()
         return 1;
 
     /* Saving current run data... */
-    sprintf(buffer, "%04d/%02d/%02d %02d:%02d:%02d", g_cur_year, g_cur_month, g_cur_day, g_cur_hour, g_cur_min, g_cur_sec);
+    snprintf(buffer, sizeof(buffer), "%04d/%02d/%02d %02d:%02d:%02d", g_cur_year, g_cur_month, g_cur_day, g_cur_hour, g_cur_min, g_cur_sec);
     VPRINT(VERBOSE1, "%s [%s]\n", _("Saving current run data..."), buffer);
 
     /* first, save the easy stuff */
     /* Header record */
-    sprintf(buffer, "# AWFFull V%s Incremental Data - %02d/%02d/%04d %02d:%02d:%02d\n", version, g_cur_month, g_cur_day, g_cur_year, g_cur_hour, g_cur_min, g_cur_sec);
+    snprintf(buffer, sizeof(buffer), "# AWFFull V%s Incremental Data - %02d/%02d/%04d %02d:%02d:%02d\n", version, g_cur_month, g_cur_day, g_cur_year, g_cur_hour, g_cur_min,
+             g_cur_sec);
     if (fputs(buffer, fp) == EOF)
         return 1;                               /* error exit */
 
     /* Current date/time          */
-    sprintf(buffer, "%d %d %d %d %d %d\n", g_cur_year, g_cur_month, g_cur_day, g_cur_hour, g_cur_min, g_cur_sec);
+    snprintf(buffer, sizeof(buffer), "%d %d %d %d %d %d\n", g_cur_year, g_cur_month, g_cur_day, g_cur_hour, g_cur_min, g_cur_sec);
     if (fputs(buffer, fp) == EOF)
         return 1;                               /* error exit */
 
     /* Monthly totals for sites, urls, etc... */
-    sprintf(buffer, "%lu %lu %lu %lu %lu %lu %llu %lu %lu %lu %lu %lu %lu\n", t_hit, t_file, t_site, t_url, t_ref, t_agent, t_xfer, t_page, t_visit, t_user, t_bookmarks, t_bad,
-            t_ignored);
+    snprintf(buffer, sizeof(buffer), "%lu %lu %lu %lu %lu %lu %llu %lu %lu %lu %lu %lu %lu\n", t_hit, t_file, t_site, t_url, t_ref, t_agent, t_xfer, t_page, t_visit, t_user,
+             t_bookmarks, t_bad, t_ignored);
     if (fputs(buffer, fp) == EOF)
         return 1;                               /* error exit */
 
     /* Daily totals for sites, urls, etc... */
-    sprintf(buffer, "%lu %lu %lu %d %d\n", dt_site, ht_hit, mh_hit, f_day, l_day);
+    snprintf(buffer, sizeof(buffer), "%lu %lu %lu %d %d\n", dt_site, ht_hit, mh_hit, f_day, l_day);
     if (fputs(buffer, fp) == EOF)
         return 1;                               /* error exit */
 
     /* Monthly (by day) total array */
     for (i = 0; i < 31; i++) {
-        sprintf(buffer, "%lu %lu %llu %lu %lu %lu %lu\n", tm_hit[i], tm_file[i], tm_xfer[i], tm_site[i], tm_page[i], tm_visit[i], tm_bookm[i]);
+        snprintf(buffer, sizeof(buffer), "%lu %lu %llu %lu %lu %lu %lu\n", tm_hit[i], tm_file[i], tm_xfer[i], tm_site[i], tm_page[i], tm_visit[i], tm_bookm[i]);
         if (fputs(buffer, fp) == EOF)
             return 1;                           /* error exit */
     }
 
     /* Daily (by hour) total array */
     for (i = 0; i < 24; i++) {
-        sprintf(buffer, "%lu %lu %llu %lu %lu\n", th_hit[i], th_file[i], th_xfer[i], th_page[i], th_bookm[i]);
+        snprintf(buffer, sizeof(buffer), "%lu %lu %llu %lu %lu\n", th_hit[i], th_file[i], th_xfer[i], th_page[i], th_bookm[i]);
         if (fputs(buffer, fp) == EOF)
             return 1;                           /* error exit */
     }
 
     /* Response codes */
     for (i = 0; i < TOTAL_RC; i++) {
-        sprintf(buffer, "%lu\n", response[i].count);
+        snprintf(buffer, sizeof(buffer), "%lu\n", response[i].count);
         if (fputs(buffer, fp) == EOF)
             return 1;                           /* error exit */
     }
@@ -247,8 +248,8 @@ save_state()
     for (i = 0; i < MAXHASH; i++) {
         uptr = um_htab[i];
         while (uptr != NULL) {
-            sprintf(buffer, "%s\n%d %lu %lu %llu %lu %lu %lu %llu\n", uptr->string, uptr->flag, uptr->count, uptr->files, uptr->xfer, uptr->entry, uptr->exit, uptr->pcount,
-                    uptr->pxfer);
+            snprintf(buffer, sizeof(buffer), "%s\n%d %lu %lu %llu %lu %lu %lu %llu\n", uptr->string, uptr->flag, uptr->count, uptr->files, uptr->xfer, uptr->entry, uptr->exit,
+                     uptr->pcount, uptr->pxfer);
             if (fputs(buffer, fp) == EOF)
                 return 1;
             uptr = uptr->next;
@@ -264,8 +265,8 @@ save_state()
     for (i = 0; i < MAXHASH; i++) {
         hptr = sm_htab[i];
         while (hptr != NULL) {
-            sprintf(buffer, "%s\n%d %lu %lu %llu %lu %lu %lu\n%s\n", hptr->string, hptr->flag, hptr->count, hptr->files, hptr->xfer, hptr->visit, hptr->pages, hptr->tstamp,
-                    (hptr->lasturl == blank_str) ? "-" : hptr->lasturl);
+            snprintf(buffer, sizeof(buffer), "%s\n%d %lu %lu %llu %lu %lu %lu\n%s\n", hptr->string, hptr->flag, hptr->count, hptr->files, hptr->xfer, hptr->visit, hptr->pages,
+                     hptr->tstamp, (hptr->lasturl == blank_str) ? "-" : hptr->lasturl);
             if (fputs(buffer, fp) == EOF)
                 return 1;                       /* error exit */
             hptr = hptr->next;
@@ -280,8 +281,8 @@ save_state()
     for (i = 0; i < MAXHASH; i++) {
         hptr = sd_htab[i];
         while (hptr != NULL) {
-            sprintf(buffer, "%s\n%d %lu %lu %llu %lu %lu\n%s\n", hptr->string, hptr->flag, hptr->count, hptr->files, hptr->xfer, hptr->visit, hptr->tstamp,
-                    (hptr->lasturl == blank_str) ? "-" : hptr->lasturl);
+            snprintf(buffer, sizeof(buffer), "%s\n%d %lu %lu %llu %lu %lu\n%s\n", hptr->string, hptr->flag, hptr->count, hptr->files, hptr->xfer, hptr->visit, hptr->tstamp,
+                     (hptr->lasturl == blank_str) ? "-" : hptr->lasturl);
             if (fputs(buffer, fp) == EOF)
                 return 1;
             hptr = hptr->next;
@@ -297,7 +298,7 @@ save_state()
         for (i = 0; i < MAXHASH; i++) {
             rptr = rm_htab[i];
             while (rptr != NULL) {
-                sprintf(buffer, "%s\n%d %lu\n", rptr->string, rptr->flag, rptr->count);
+                snprintf(buffer, sizeof(buffer), "%s\n%d %lu\n", rptr->string, rptr->flag, rptr->count);
                 if (fputs(buffer, fp) == EOF)
                     return 1;                   /* error exit */
                 rptr = rptr->next;
@@ -314,7 +315,7 @@ save_state()
         for (i = 0; i < MAXHASH; i++) {
             aptr = am_htab[i];
             while (aptr != NULL) {
-                sprintf(buffer, "%s\n%d %lu\n", aptr->string, aptr->flag, aptr->count);
+                snprintf(buffer, sizeof(buffer), "%s\n%d %lu\n", aptr->string, aptr->flag, aptr->count);
                 if (fputs(buffer, fp) == EOF)
                     return 1;                   /* error exit */
                 aptr = aptr->next;
@@ -330,7 +331,7 @@ save_state()
     for (i = 0; i < MAXHASH; i++) {
         sptr = sr_htab[i];
         while (sptr != NULL) {
-            sprintf(buffer, "%s\n%lu\n", sptr->string, sptr->count);
+            snprintf(buffer, sizeof(buffer), "%s\n%lu\n", sptr->string, sptr->count);
             if (fputs(buffer, fp) == EOF)
                 return 1;                       /* error exit */
             sptr = sptr->next;
@@ -346,7 +347,7 @@ save_state()
     for (i = 0; i < MAXHASH; i++) {
         iptr = im_htab[i];
         while (iptr != NULL) {
-            sprintf(buffer, "%s\n%d %lu %lu %llu %lu %lu\n", iptr->string, iptr->flag, iptr->count, iptr->files, iptr->xfer, iptr->visit, iptr->tstamp);
+            snprintf(buffer, sizeof(buffer), "%s\n%d %lu %lu %llu %lu %lu\n", iptr->string, iptr->flag, iptr->count, iptr->files, iptr->xfer, iptr->visit, iptr->tstamp);
             if (fputs(buffer, fp) == EOF)
                 return 1;                       /* error exit */
             iptr = iptr->next;
@@ -362,7 +363,7 @@ save_state()
     for (i = 0; i < MAXHASH; i++) {
         eptr = ep_htab[i];
         while (eptr != NULL) {
-            sprintf(buffer, "%s\n%lu\n%s\n", eptr->url, eptr->count, eptr->referer);
+            snprintf(buffer, sizeof(buffer), "%s\n%lu\n%s\n", eptr->url, eptr->count, eptr->referer);
             if (fputs(buffer, fp) == EOF)
                 return 1;
             eptr = eptr->next;
